//author: Jessica Su
//program: 6_analytic_sample.do
//project: do file that creates analytic sample and sexism indices

* Define path globals
global data "D:/ahd/researchers/jhs/jhs_projects/data"
global log "D:/ahd/researchers/jhs/jhs_projects/log_files/sexism replication logs"
global sysdate=c(current_date)

cap log close
set more off
cd "$log"
log using "6_analytic_sample_$sysdate.log", replace
use "$data/jhs_context_long", clear

**************************************************************************************
//Analytic sample
xtset aid age
xtdescribe
//These data are in long format, with person-year observation from ages 9-30
//n=20745 *22

//Look at observations from age 15-21
//this is just narrowing down the observation window for early first birth 
//note that Rs could still be <15 at wave 1
drop if age<15 | age>21
//n=20745 * 7= 145,215

//Create subpop flag
gen sample=1
xttab sample

//Exclusion criteria
//Drop if male
replace sample=0 if female==0
xttab sample

//Drop if don't have valid sampling weight (some oversamples due to genetic sample)
replace sample=0 if gswgt1==.
xttab sample

//drop if no geocode match for contextual data
replace sample=0 if match==0
xttab sample

//Drop if did not participate in wave 4 interview or wave 5 interview
replace sample=0 if wave4!=1 & wave5!=1
xttab sample

//Drop if missing outcome variables
replace sample=0 if firstbirth==. 
xttab sample

//Drop if first birth before wave 1 interview
replace sample=0 if b1birthdate4<w1intdate & w1intdate!=. 
xttab sample 

//Drop person-year obs that occurred before wave 1
replace sample=0 if year<1994
xttab sample

//Drop person-year obs no longer at risk
replace sample=0 if firstbirth==2
xttab sample

//Drop respondents who were 17 or older at wave 1
tab age1 sample 
xttab age1 if sample==1
replace sample=0 if age1>=17
xttab sample

//Institutional Sexism variables
replace sample=0 if cacw1mflabor==.
xttab sample
replace sample=0 if ccu92a28==.
xttab sample
replace sample=0 if ccm90a15==.
xttab sample
replace sample=0 if w1limabortfund==.
xttab sample
replace sample=0 if w1informconsent==.
xttab sample
replace sample=0 if w1parconsent==.
xttab sample
replace sample=0 if w1noabprov==.
xttab sample

//Interactional Sexism variables
replace sample=0 if smfunwt_sexposnorms==. 
xttab sample
replace sample=0 if smfunwt_idealrel_sex==.  
xttab sample
replace sample=0 if smfunwt_momapprovesex==. 
xttab sample
replace sample=0 if sfmunwt_housework==. 
xttab sample
replace sample=0 if smfunwt_hrwage_school==.
xttab sample
replace sample=0 if avgr1mfage==.
xttab sample
replace sample=0 if avgscripture==.
xttab sample

//Time-invariant control variables
replace sample=0 if racecat1==.
xttab sample
replace sample=0 if borninus==.
xttab sample
replace sample=0 if w1famst==.
xttab sample
replace sample=0 if paredu1==.
xttab sample
replace sample=0 if w1cpovquint==.
xttab sample
replace sample=0 if countyblack==.
xttab sample
replace sample=0 if countyhispanic==.
xttab sample

egen perfemale = mean(female), by(scid) 
replace perfemale=. if perfemale<.3 | perfemale>.7
replace sample=0 if perfemale==.
xttab sample


//age at wave 1
xttab age1 if sample==1
tab year if sample==1

//first birth by age at wave 1
tab age1 firstbirth if sample==1
tab age1 firstbirth if sample==0

xttab age1 if sample==1
xttab age1 if sample==0 & female==1

tab age firstbirth if sample==1
tab age firstbirth if sample==0
tab age firstbirth if sample==0 & (b1birthdate4<w1intdate & w1intdate!=.) 
tab age firstbirth if sample==0 & (b1birthdate4>=w1intdate & w1intdate!=.) & (age1>=17)


/////////////////////////////
//INSTITUTIONAL SEXISM
////////////////////////////
/*
Economic conditions
	cacw1mflabor

Cultural ideology
	ccu92a28 
	ccm90a15 
	
Reproductive health resources
	w1limabortfund 
	w1informconsent 
	w1parconsent 
	w1noabprov 
*/

global institutional_standard cacw1mflabor ccu92a28 ccm90a15 w1limabortfund w1informconsent w1parconsent w1noabprov 
sum $institutional_standard 

//Standardize measures
foreach var in $institutional_standard {
		egen z`var' = std(`var') if sample==1
}
sum z* if sample==1


alpha zcacw1mflabor zccu92a28 zccm90a15 zw1limabortfund zw1informconsent zw1parconsent zw1noabprov if sample==1, asis item detail
egen institutional_sexism=rsum(zcacw1mflabor zccu92a28 zccm90a15 zw1limabortfund zw1informconsent zw1parconsent zw1noabprov) if sample==1

/////////////////////////////
//INTERACTIONAL SEXISM
////////////////////////////

/*
Gendered norms	
	smf_sexposnorms
	smfunwt_idealrel_sex
	smf_momapprovesex
	
Power in relationships	
	sfmunwt_housework
	smf_hrwage_school
	avgr1mfage
	
Traditional gender role ideology
	avgscripture
*/

global interact_unwt  smfunwt_sexposnorms smfunwt_idealrel_sex smfunwt_momapprovesex sfmunwt_housework smfunwt_hrwage_school avgr1mfage  avgscripture 
sum $interact_unwt if sample==1

//Standardize measures
foreach var in $interact_unwt {
		egen z`var' = std(`var') if sample==1
}
sum z* if sample==1


alpha zsmfunwt_sexposnorms zsmfunwt_idealrel_sex zsmfunwt_momapprovesex zsfmunwt_housework zsmfunwt_hrwage_school zavgr1mfage  zavgscripture if sample==1, item detail
egen interaction_sexism_unwt=rsum(zsmfunwt_sexposnorms zsmfunwt_idealrel_sex zsmfunwt_momapprovesex zsfmunwt_housework zsmfunwt_hrwage_school zavgr1mfage  zavgscripture) if sample==1

egen nmiss_intersexism=rowmiss(zsmfunwt_sexposnorms zsmfunwt_idealrel_sex zsmfunwt_momapprovesex zsfmunwt_housework zsmfunwt_hrwage_school zavgr1mfage  zavgscripture)
tab nmiss_intersexism
replace interaction_sexism_unwt=. if nmiss_intersexism>=7

sum institutional_sexism interaction_sexism_unwt if sample==1
//standardize sexism indices so they have mean 0, std. dev 1
//These measures already have a mean of 0 because it is a sum of standardized measures;
//just need to divide by standard deviation so a 1-unit change is a 1-std. dev change

foreach var of varlist institutional_sexism interaction_sexism_unwt {
	sum `var', detail
	replace `var'=`var'/`r(sd)'
}

sum institutional_sexism interaction_sexism_unwt if sample==1

save "$data/jhs_sexism_analysis", replace
log close
exit
